@@ -48,6 +48,11 @@ func main() {
 		log.Fatal(err)
 	}
 
+	err = cleanDocumentation()
+	if err != nil {
+		log.Fatal(err)
+	}
+
 	for _, m := range models.Providers {
 		// generate documentation
 		err = generateDocumentation(m)
@@ -71,6 +76,22 @@ func main() {
 	fmt.Printf("Documentation for %d DNS providers has been generated.\n", len(models.Providers)+1)
 }
 
+func cleanDocumentation() error {
+	paths, err := filepath.Glob(filepath.Join(docOutput, "zz_gen_*.md"))
+	if err != nil {
+		return err
+	}
+
+	for _, p := range paths {
+		err = os.RemoveAll(p)
+		if err != nil {
+			return err
+		}
+	}
+
+	return nil
+}
+
 func generateDocumentation(m descriptors.Provider) error {
 	filename := filepath.Join(docOutput, "zz_gen_"+m.Code+".md")
 
@@ -95,6 +116,7 @@ func generateCLIHelp(models *descriptors.Providers) error {
 	defer func() { _ = file.Close() }()
 
 	b := &bytes.Buffer{}
+
 	err = template.Must(
 		template.New(filepath.Base(cliTemplate)).Funcs(map[string]any{
 			"safe": func(src string) string {
@@ -113,6 +135,7 @@ func generateCLIHelp(models *descriptors.Providers) error {
 	}
 
 	_, err = file.Write(source)
+
 	return err
 }
 
@@ -140,6 +163,7 @@ func generateReadMe(models *descriptors.Providers) error {
 			if err = tpl.Execute(buffer, providers); err != nil {
 				return err
 			}
+
 			skip = true
 		}
 
@@ -177,8 +201,10 @@ func orderProviders(models *descriptors.Providers) [][]descriptors.Provider {
 		return strings.Compare(strings.ToLower(a.Name), strings.ToLower(b.Name))
 	})
 
-	var matrix [][]descriptors.Provider
-	var row []descriptors.Provider
+	var (
+		matrix [][]descriptors.Provider
+		row    []descriptors.Provider
+	)
 
 	for i, p := range providers {
 		switch {
@@ -191,6 +217,7 @@ func orderProviders(models *descriptors.Providers) [][]descriptors.Provider {
 			for j := len(row); j < nbCol; j++ {
 				row = append(row, descriptors.Provider{})
 			}
+
 			matrix = append(matrix, row)
 
 		default:
@@ -202,6 +229,7 @@ func orderProviders(models *descriptors.Providers) [][]descriptors.Provider {
 		for j := len(row); j < nbCol; j++ {
 			row = append(row, descriptors.Provider{})
 		}
+
 		matrix = append(matrix, row)
 	}
 
