@@ -2,13 +2,15 @@
 package alidns
 
 import (
+	"context"
 	"errors"
 	"fmt"
 	"time"
 
-	alidns "github.com/alibabacloud-go/alidns-20150109/v4/client"
 	openapi "github.com/alibabacloud-go/darabonba-openapi/v2/client"
+	"github.com/alibabacloud-go/tea/dara"
 	"github.com/aliyun/credentials-go/credentials"
+	alidns "github.com/go-acme/alidns-20150109/v4/client"
 	"github.com/go-acme/lego/v4/challenge"
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
@@ -150,9 +152,11 @@ func (d *DNSProvider) Timeout() (timeout, interval time.Duration) {
 
 // Present creates a TXT record to fulfill the dns-01 challenge.
 func (d *DNSProvider) Present(domain, token, keyAuth string) error {
+	ctx := context.Background()
+
 	info := dns01.GetChallengeInfo(domain, keyAuth)
 
-	zoneName, err := d.getHostedZone(info.EffectiveFQDN)
+	zoneName, err := d.getHostedZone(ctx, info.EffectiveFQDN)
 	if err != nil {
 		return fmt.Errorf("alicloud: %w", err)
 	}
@@ -162,23 +166,26 @@ func (d *DNSProvider) Present(domain, token, keyAuth string) error {
 		return err
 	}
 
-	_, err = d.client.AddDomainRecord(recordRequest)
+	_, err = alidns.AddDomainRecordWithContext(ctx, d.client, recordRequest, &dara.RuntimeOptions{})
 	if err != nil {
 		return fmt.Errorf("alicloud: API call failed: %w", err)
 	}
+
 	return nil
 }
 
 // CleanUp removes the TXT record matching the specified parameters.
 func (d *DNSProvider) CleanUp(domain, token, keyAuth string) error {
+	ctx := context.Background()
+
 	info := dns01.GetChallengeInfo(domain, keyAuth)
 
-	records, err := d.findTxtRecords(info.EffectiveFQDN)
+	records, err := d.findTxtRecords(ctx, info.EffectiveFQDN)
 	if err != nil {
 		return fmt.Errorf("alicloud: %w", err)
 	}
 
-	_, err = d.getHostedZone(info.EffectiveFQDN)
+	_, err = d.getHostedZone(ctx, info.EffectiveFQDN)
 	if err != nil {
 		return fmt.Errorf("alicloud: %w", err)
 	}
@@ -188,15 +195,16 @@ func (d *DNSProvider) CleanUp(domain, token, keyAuth string) error {
 			RecordId: rec.RecordId,
 		}
 
-		_, err = d.client.DeleteDomainRecord(request)
+		_, err = alidns.DeleteDomainRecordWithContext(ctx, d.client, request, &dara.RuntimeOptions{})
 		if err != nil {
 			return fmt.Errorf("alicloud: %w", err)
 		}
 	}
+
 	return nil
 }
 
-func (d *DNSProvider) getHostedZone(domain string) (string, error) {
+func (d *DNSProvider) getHostedZone(ctx context.Context, domain string) (string, error) {
 	request := new(alidns.DescribeDomainsRequest)
 
 	var domains []*alidns.DescribeDomainsResponseBodyDomainsDomain
@@ -206,7 +214,7 @@ func (d *DNSProvider) getHostedZone(domain string) (string, error) {
 	for {
 		request.SetPageNumber(startPage)
 
-		response, err := d.client.DescribeDomains(request)
+		response, err := alidns.DescribeDomainsWithContext(ctx, d.client, request, &dara.RuntimeOptions{})
 		if err != nil {
 			return "", fmt.Errorf("API call failed: %w", err)
 		}
@@ -226,6 +234,7 @@ func (d *DNSProvider) getHostedZone(domain string) (string, error) {
 	}
 
 	var hostedZone *alidns.DescribeDomainsResponseBodyDomainsDomain
+
 	for _, zone := range domains {
 		if ptr.Deref(zone.DomainName) == dns01.UnFqdn(authZone) || ptr.Deref(zone.PunyCode) == dns01.UnFqdn(authZone) {
 			hostedZone = zone
@@ -253,8 +262,8 @@ func (d *DNSProvider) newTxtRecord(zone, fqdn, value string) (*alidns.AddDomainR
 		SetTTL(int64(d.config.TTL)), nil
 }
 
-func (d *DNSProvider) findTxtRecords(fqdn string) ([]*alidns.DescribeDomainRecordsResponseBodyDomainRecordsRecord, error) {
-	zoneName, err := d.getHostedZone(fqdn)
+func (d *DNSProvider) findTxtRecords(ctx context.Context, fqdn string) ([]*alidns.DescribeDomainRecordsResponseBodyDomainRecordsRecord, error) {
+	zoneName, err := d.getHostedZone(ctx, fqdn)
 	if err != nil {
 		return nil, err
 	}
@@ -265,7 +274,7 @@ func (d *DNSProvider) findTxtRecords(fqdn string) ([]*alidns.DescribeDomainRecor
 
 	var records []*alidns.DescribeDomainRecordsResponseBodyDomainRecordsRecord
 
-	result, err := d.client.DescribeDomainRecords(request)
+	result, err := alidns.DescribeDomainRecordsWithContext(ctx, d.client, request, &dara.RuntimeOptions{})
 	if err != nil {
 		return records, fmt.Errorf("API call has failed: %w", err)
 	}
@@ -280,6 +289,7 @@ func (d *DNSProvider) findTxtRecords(fqdn string) ([]*alidns.DescribeDomainRecor
 			records = append(records, record)
 		}
 	}
+
 	return records, nil
 }
 
