@@ -6,7 +6,7 @@ import (
 )
 
 type APIResponse[T any] struct {
-	Metadata Metadata `json:"metadata,omitempty"`
+	Metadata Metadata `json:"metadata"`
 	Data     T        `json:"data,omitempty"`
 
 	Status   int      `json:"status,omitempty"`
