@@ -165,7 +165,7 @@ func (d *DNSProvider) getHostedZone(domain string) (string, string, error) {
 	}
 
 	if hostedZone.ID == "" || hostedZone.ID == "0" {
-		return "", "", fmt.Errorf("zone %s not found in dnspod for domain %s", authZone, domain)
+		return "", "", fmt.Errorf("zone %s not found for domain %s", authZone, domain)
 	}
 
 	return hostedZone.ID.String(), hostedZone.Name, nil
