@@ -16,6 +16,7 @@ import (
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
 	"github.com/go-acme/lego/v4/providers/dns/easydns/internal"
+	"github.com/go-acme/lego/v4/providers/dns/internal/clientdebug"
 )
 
 // Environment variables names.
@@ -77,6 +78,7 @@ func NewDNSProvider() (*DNSProvider, error) {
 	if err != nil {
 		return nil, fmt.Errorf("easydns: %w", err)
 	}
+
 	config.Endpoint = endpoint
 
 	values, err := env.Get(EnvToken, EnvKey)
@@ -110,6 +112,8 @@ func NewDNSProviderConfig(config *Config) (*DNSProvider, error) {
 		client.HTTPClient = config.HTTPClient
 	}
 
+	client.HTTPClient = clientdebug.Wrap(client.HTTPClient)
+
 	if config.Endpoint != nil {
 		client.BaseURL = config.Endpoint
 	}
@@ -189,6 +193,7 @@ func (d *DNSProvider) CleanUp(domain, token, keyAuth string) error {
 
 	d.recordIDsMu.Lock()
 	defer delete(d.recordIDs, key)
+
 	d.recordIDsMu.Unlock()
 
 	if err != nil {
