@@ -9,10 +9,22 @@ import (
 	teo "github.com/go-acme/tencentedgdeone/v20220901"
 )
 
-func (d *DNSProvider) getHostedZone(ctx context.Context, domain string) (*teo.Zone, error) {
+func (d *DNSProvider) getHostedZoneID(ctx context.Context, domain string) (*string, error) {
+	authZone, err := dns01.FindZoneByFqdn(domain)
+	if err != nil {
+		return nil, fmt.Errorf("could not find zone: %w", err)
+	}
+
+	if d.config.ZonesMapping != nil {
+		zoneID, ok := d.config.ZonesMapping[authZone]
+		if ok {
+			return ptr.Pointer(zoneID), nil
+		}
+	}
+
 	request := teo.NewDescribeZonesRequest()
 
-	var domains []*teo.Zone
+	var zones []*teo.Zone
 
 	for {
 		response, err := teo.DescribeZonesWithContext(ctx, d.client, request)
@@ -20,23 +32,18 @@ func (d *DNSProvider) getHostedZone(ctx context.Context, domain string) (*teo.Zo
 			return nil, fmt.Errorf("API call failed: %w", err)
 		}
 
-		domains = append(domains, response.Response.Zones...)
+		zones = append(zones, response.Response.Zones...)
 
-		if int64(len(domains)) >= ptr.Deref(response.Response.TotalCount) {
+		if int64(len(zones)) >= ptr.Deref(response.Response.TotalCount) {
 			break
 		}
 
-		request.Offset = ptr.Pointer(int64(len(domains)))
-	}
-
-	authZone, err := dns01.FindZoneByFqdn(domain)
-	if err != nil {
-		return nil, fmt.Errorf("could not find zone: %w", err)
+		request.Offset = ptr.Pointer(int64(len(zones)))
 	}
 
 	var hostedZone *teo.Zone
 
-	for _, zone := range domains {
+	for _, zone := range zones {
 		unfqdn := dns01.UnFqdn(authZone)
 		if ptr.Deref(zone.ZoneName) == unfqdn {
 			hostedZone = zone
@@ -44,8 +51,8 @@ func (d *DNSProvider) getHostedZone(ctx context.Context, domain string) (*teo.Zo
 	}
 
 	if hostedZone == nil {
-		return nil, fmt.Errorf("zone %s not found in dnspod for domain %s", authZone, domain)
+		return nil, fmt.Errorf("zone %s not found for domain %s", authZone, domain)
 	}
 
-	return hostedZone, nil
+	return hostedZone.ZoneId, nil
 }
